import sys
from pathlib import Path


def pytest_configure():
    import otree_startup
    import django
    import os

    # CI should run from tests/ dir, because it needs to run "otree collectstatic" first, and I can't put
    # 'cd tests' in tox.ini commands, because i get some error like "cd executable not found"
    # during local testing, static root typically already exists, so we can skip collectstatic
    # and therefore run pytest from root repo dir.

    # ideally we could do everything from tests/ dir, so that tests.py doesn't have to identify apps as
    # "tests.app_name" (which affects various test code that refers to the app name)
    # but to do that, i need to add tests/ to sys.path, but root dir is already there, so I get a
    # "duplicate app label" error. and I couldn't figure out a way to remove it.

    # why am i able to run pytest from tests/ dir? Because both ./core and ./core/tests are on sys.path,
    # so why doesn't that cause the "duplicate app label" error?
    if Path('tests').is_dir():
        os.chdir('tests')
    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "tests.settings")
    DJANGO_SETTINGS_MODULE = os.environ['DJANGO_SETTINGS_MODULE']

    otree_startup.configure_settings(DJANGO_SETTINGS_MODULE)
    django.setup()

    otree_startup.PYPI_CHECK_UPDATES = False

    # TODO: could/should `django_settings` fixture maybe.
    from django.conf import settings

    # To make tests run faster, autorefresh should be set to True
    # http://whitenoise.evans.io/en/latest/django.html#whitenoise-makes-my-tests-run-slow
    settings.WHITENOISE_AUTOREFRESH = True

    # TODO: should use custom test settings probably?!
    import logging

    logger = logging.getLogger('otree')
    logger.setLevel(logging.WARNING)
