# -*- coding: utf-8 -*-

from otree.api import Bot, expect

from . import pages
from .models import Constants


class PlayerBot(Bot):
    def play_round(self):
        # it should be set right away, after initializeparticipant
        expect(self.player.start_count, 1)

        # this is the problem. play_round() will only get evaluated when we need to pass a page.
        # if the player skips round 1,
        # this bot is not called until they reach the first page on round 2.
        # normally that is irrelevant, because the player's fields change only when they pass through a page.
        # so there is no confusion. it's all about whether they have submitted that specific page yet.
        # but here, it's dependent on the round number instead.
        # (But what about is_displayed? try setting a variable there, i expect the same thing will happen
        # i guess that's why i don't encourage people to set things in is_displayed anyway,
        # how about with vars_for_template? i think that same issue will happen.
        # i guess the problem is assertions after the last yield.
        # and people doing that probably realize it's a hack, and we don't have idempotency there,
        # so if you are incrementing a counter it won't work)
        # so, i think i should fix how the bot system works.
        # when can we trigger it to complete all asserts in the bot? i guess before we run .start() or .is_displayed()
        # on an upcoming app. how can we signal that? we need to communicate back from the view back to the bot that .start()
        # is ABOUT to be run, so complete the bot. seems complicated.
        # or what if we make .start() run only before displaying or passing through a page?
        # is there any use in doing .start() if all pages are skipped?
        # by the way this will be an advantage over .is_displayed().
        # but that means it will need to run AFTER .is_displayed(), which seems counterintuitive.
        # shouldn't do that.
        # because this feature doesn't work well with bots, i guess i will not include it.
        # or put a caveat? or isn't it such a special/rare case? bot in a round where all pages
        # are skipped. and it only happens when an assert is used.
        # HERE is the problematic line:
        # expect(self.participant.vars['start_count'], self.round_number)
        expect(self.participant.vars['start_count'], '>=', self.round_number)
        if self.round_number == 2:
            expect(self.player.start_count, 1)
            expect(self.participant.vars['start_count'], self.round_number)
            yield pages.MyPage
            yield pages.Results
