import os
from os import environ

import otree.settings
from django.conf.global_settings import STATICFILES_STORAGE  # noqa

import dj_database_url


if os.environ.get('BROWSER_BOTS_USE_HEADLESS'):
    DEBUG = True
else:
    AUTH_LEVEL = 'STUDY'
    DEBUG = False

ADMIN_PASSWORD = 'otree'
SECRET_KEY = 'zzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzz'

'''
environ['DATABASE_URL'] = 'postgres://postgres@localhost/django_db'


DATABASES = {
    'default': dj_database_url.config(
        default='sqlite:///' + os.path.join(BASE_DIR, 'db.sqlite3')
    )
}
'''

# 2017-06-13: why did i have it hardcoded previously? maybe because SQLite is faster?
# 2017-07-16: because postgres gives me an error, even after i reset the DB:
#    django.db.utils.ProgrammingError: relation "otree_session" does not exist

# 2017-06-13: why did i have it hardcoded previously? maybe because SQLite is faster?


ADMIN_USERNAME = 'admin'

# should keep these so i can run my MTurk tests
AWS_ACCESS_KEY_ID = environ.get('AWS_ACCESS_KEY_ID')
AWS_SECRET_ACCESS_KEY = environ.get('AWS_SECRET_ACCESS_KEY')

# e.g. EUR, CAD, GBP, CHF, CNY, JPY
REAL_WORLD_CURRENCY_CODE = 'EUR'
USE_POINTS = False

# e.g. en-gb, de-de, it-it, fr-fr.
# see: https://docs.djangoproject.com/en/1.7/topics/i18n/
LANGUAGE_CODE = 'en'

INSTALLED_APPS = ['otree', 'tests']

SESSION_CONFIG_DEFAULTS = {
    'real_world_currency_per_point': 0.01,
    'participation_fee': 10.00,
    'doc': "",
    'use_browser_bots': False,
}

SESSION_CONFIGS = [
    dict(name='simple', num_demo_participants=1, app_sequence=['tests.simple']),
    dict(
        name='saving',
        num_demo_participants=1,
        participation_fee=9.99,
        real_world_currency_per_point=0.02,
        app_sequence=['tests.saving'],
        treatment='blue',
    ),
    dict(
        name='misc_3p',
        num_demo_participants=3,
        app_sequence=['tests.misc_3p'],
        use_browser_bots=True,
    ),
    dict(
        name='two_simple_games',
        num_demo_participants=1,
        app_sequence=['tests.simple', 'tests.saving'],
    ),
    dict(name='skip_many', num_demo_participants=2, app_sequence=['tests.skip_many']),
    dict(name='rounds', num_demo_participants=4, app_sequence=['tests.rounds']),
    dict(
        name='advance_slowest',
        num_demo_participants=2,
        app_sequence=['tests.advance_slowest'],
    ),
    dict(
        name='advance_slowest_wait',
        num_demo_participants=2,
        app_sequence=['tests.advance_slowest_wait'],
    ),
    dict(name='wait_page', num_demo_participants=2, app_sequence=['tests.wait_page']),
    dict(
        name='skip_wait_page',
        num_demo_participants=2,
        app_sequence=['tests.skip_wait_page'],
    ),
    dict(
        name='waitpage_set_field',
        num_demo_participants=4,
        app_sequence=['tests.waitpage_set_field'],
    ),
    dict(
        name='waitpage_skip_race',
        num_demo_participants=2,
        app_sequence=['tests.waitpage_skip_race'],
    ),
    dict(
        name='waitpage_skip_aapa',
        num_demo_participants=2,
        app_sequence=['tests.waitpage_skip_aapa'],
    ),
    dict(
        name='skip_waitpage_lookahead',
        num_demo_participants=2,
        app_sequence=['tests.skip_waitpage_lookahead'],
        use_browser_bots=True,
    ),
    dict(
        name='form_validation',
        num_demo_participants=1,
        app_sequence=['tests.form_validation'],
    ),
    dict(name='export', num_demo_participants=1, app_sequence=['tests.export']),
    dict(
        name='bots_raise',
        num_demo_participants=1,
        app_sequence=['tests.bots_empty', 'tests.bots_raise'],
    ),
    dict(
        name='gbat',
        num_demo_participants=6,
        app_sequence=['tests.gbat'],
        use_browser_bots=True,
    ),
    dict(
        name='gbat_round1',
        num_demo_participants=6,
        app_sequence=['tests.gbat_round1'],
        use_browser_bots=True,
    ),
    dict(
        name='gbat_custom',
        num_demo_participants=6,
        app_sequence=['tests.gbat_custom'],
        use_browser_bots=True,
    ),
    dict(
        name='gbat_heartbeat',
        num_demo_participants=4,
        app_sequence=['tests.gbat_heartbeat'],
    ),
    dict(
        name='gbat_group_others',
        num_demo_participants=4,
        app_sequence=['tests.gbat_group_others'],
    ),
    dict(
        name='bots_simple', num_demo_participants=1, app_sequence=['tests.bots_simple']
    ),
    dict(
        name='bots_check_html',
        num_demo_participants=1,
        app_sequence=['tests.bots_check_html'],
    ),
    dict(
        name='bots_bad_post',
        num_demo_participants=1,
        app_sequence=['tests.bots_bad_post'],
    ),
    dict(name='bots_cases', num_demo_participants=1, app_sequence=['tests.bots_cases']),
    dict(
        name='templates_app',
        num_demo_participants=1,
        app_sequence=['tests.templates_app'],
    ),
    dict(name='i18n', num_demo_participants=1, app_sequence=['tests.i18n']),
    dict(
        name='admin_report',
        num_demo_participants=1,
        app_sequence=['tests.admin_report', 'tests.admin_report_legacy'],
    ),
    dict(
        name='two_rounds_1p',
        num_demo_participants=1,
        app_sequence=['tests.two_rounds_1p'],
        real_world_currency_per_point=0.5,
        participation_fee=1.25,
    ),
    dict(
        name='timeout_submission',
        num_demo_participants=1,
        app_sequence=['tests.timeout_submission'],
    ),
    dict(name='constants', num_demo_participants=1, app_sequence=['tests.constants']),
    dict(
        name='waitpage_template',
        num_demo_participants=1,
        app_sequence=['tests.waitpage_template'],
    ),
    dict(
        name='mturk',
        num_demo_participants=1,
        app_sequence=['tests.simple'],
        participation_fee=0.4,
        mturk_hit_settings={
            'keywords': ['easy', 'bonus', 'choice', 'study'],
            'title': 'Title for your experiment',
            'description': 'Description for your experiment',
            'frame_height': 500,
            'template': 'global/mturk_template.html',
            'minutes_allotted_per_assignment': 60,
            'expiration_hours': 4,  # 7 days
            # to prevent retakes
            'grant_qualification_id': 'ATESTQUAL',
            'qualification_requirements': [],
        },
    ),
    dict(
        name='edit_session_config',
        num_demo_participants=1,
        app_sequence=['tests.simple'],
        int=0,
        float=0.5,
        str='',
        use_browser_bots=False,
    ),
    dict(
        name='rest_api',
        num_demo_participants=1,
        app_sequence=['tests.simple'],
        int=0,
        float=0.5,
        list=[1, 2],
        str='',
        use_browser_bots=False,
    ),
    dict(name='query_api', num_demo_participants=2, app_sequence=['tests.query_api']),
    dict(
        name='bots_form_errors',
        num_demo_participants=1,
        app_sequence=['tests.bots_form_errors'],
    ),
    dict(name='chat', num_demo_participants=1, app_sequence=['tests.chatapp']),
    dict(
        name='form_blank_value',
        num_demo_participants=1,
        app_sequence=['tests.form_blank_value'],
    ),
    dict(name='setattr', num_demo_participants=1, app_sequence=['tests.setattr']),
    dict(name='live', num_demo_participants=2, app_sequence=['tests.live']),
    dict(
        name='javascript_vars',
        num_demo_participants=None,
        app_sequence=['tests.javascript_vars'],
    ),
    dict(
        name='waitpage_aapa_string',
        num_demo_participants=4,
        app_sequence=['tests.waitpage_aapa_string'],
    ),
    dict(
        name='app_after_this_page',
        num_demo_participants=2,
        app_sequence=['tests.aatp', 'tests.aatp_app_2', 'tests.aatp_app_3'],
    ),
    dict(
        name='player_start',
        num_demo_participants=1,
        app_sequence=['tests.player_start', 'tests.player_start_2'],
    ),
    dict(name='role', num_demo_participants=2, app_sequence=['tests.role'],),
]

ROOM_DEFAULTS = {}

ROOM_WITH_LABELS_NAME = 'with_labels'
ROOM_WITHOUT_LABELS_NAME = 'without_labels'
ROOM_WITH_SECURE_URLS_NAME = 'with_secure_urls'

ROOMS = [
    {
        'name': ROOM_WITH_LABELS_NAME,
        'display_name': ROOM_WITH_LABELS_NAME,
        'participant_label_file': 'participant_labels.txt',
        'use_secure_urls': False,
    },
    {'name': ROOM_WITHOUT_LABELS_NAME, 'display_name': ROOM_WITHOUT_LABELS_NAME},
    {
        'name': ROOM_WITH_SECURE_URLS_NAME,
        'display_name': ROOM_WITH_SECURE_URLS_NAME,
        # the correct path depends where the server was launched from
        # maybe need to prefix with tests/
        'participant_label_file': 'participant_labels.txt',
        'use_secure_urls': True,
    },
]

BOTS_CHECK_HTML = False
