from django.core import checks
from django.apps.registry import Apps
from .utils import TestCase
from importlib import import_module
from typing import List


class CheckTests(TestCase):
    def _test_app(
        self, app_label, expected_errors: List[int], expected_warnings: List[int]
    ):
        # need to import inside the method, otherwise I get:
        #   File "C:\oTree\ve_dj20\lib\site-packages\idmap\tls.py", line 30, in get_cache
        # new_cache_func = dict if cls._meta.use_strong_refs else WeakValueDictionary
        # AttributeError: 'Options' object has no attribute 'use_strong_refs'
        models_module = import_module("tests.checks.{}.models".format(app_label))
        apps = Apps(["tests.checks.{}".format(app_label)])
        for model in [
            models_module.Player,
            models_module.Group,
            models_module.Subsession,
        ]:
            apps.register_model(app_label, model)
        app_config = apps.get_app_config(app_label)
        errors = checks.run_checks(app_configs=[app_config])
        expected_errors = [
            "otree.E" + str(numeric_id).zfill(3) for numeric_id in expected_errors
        ]
        expected_warnings = [
            "otree.W" + str(numeric_id).zfill(3) for numeric_id in expected_warnings
        ]
        expected_errors_and_warnings = set(expected_errors + expected_warnings)
        actual_errors_and_warnings = set([error.id for error in errors])

        # ignore this error about foreign keys until i can figure out how to
        # solve it...it just occurs because this app is not in INSTALLED_APPS
        # i tried various tricks with isolate_apps and mocking the registry,
        # can't figure it out.
        actual_errors_and_warnings.discard("fields.E300")
        self.assertEqual(expected_errors_and_warnings, actual_errors_and_warnings)

    def test_checks(self):
        self._test_app(
            "a1",
            expected_errors=[12, 13, 14, 22, 23, 24, 25, 111, 112, 221],
            expected_warnings=[],
        )

    def test_template_checks(self):
        self._test_app("templatesapp", expected_errors=[104], expected_warnings=[])
