import otree.forms
from otree.forms import ModelForm
import splinter
from .utils import TestCase
from .models import FormFieldModel
from otree.api import BasePlayer, models, currency_range, widgets
from otree.session import create_session
from otree.bots.runner import run_bots
from unittest.mock import patch, MagicMock
from django.forms import widgets as dj_widgets


class SimpleModelForm(ModelForm):
    class Meta:
        model = FormFieldModel
        exclude = ()


class UseFloppyformWidgetsTests(TestCase):
    def test_custom_fields(self):
        self.assertIsInstance(
            SimpleModelForm.base_fields['sent_amount'], otree.forms.CurrencyChoiceField
        )

    def test_currency_field(self):
        self.assertIsInstance(
            SimpleModelForm.base_fields['currency'], otree.forms.CurrencyField
        )
        self.assertIsInstance(
            SimpleModelForm.base_fields['currency'].widget, widgets._CurrencyInput
        )
        self.assertIsInstance(
            SimpleModelForm.base_fields['currency_choice'],
            otree.forms.CurrencyChoiceField,
        )
        self.assertIsInstance(
            SimpleModelForm.base_fields['currency_choice'].widget, dj_widgets.Select
        )


class FormTests(TestCase):
    def test_bots(self):
        session = create_session('form_validation', num_participants=1)
        run_bots(session)


class BlankValueTests(TestCase):

    '''see form_blank_value pages.py'''

    @patch('tests.form_blank_value.pages.Page1.error_message')
    def test_blank(self, patched_error_message: MagicMock):
        session = create_session('form_blank_value', num_participants=1)
        participant = session.participant_set.first()
        br = self.splinter_browser
        br.visit(participant._start_url())
        next_button = br.find_by_tag('button')
        patched_error_message.assert_not_called()
        next_button.click()
        patched_error_message.assert_called()
