from unittest.mock import patch
from .utils import TestCase
import otree.session
from otree.models import Participant
from otree.live import live_payload_function
from tests.live.pages import page_sequence
from tests.live.models import Group


class TestLive(TestCase):
    def test_basic(self):

        session = otree.session.create_session(
            session_config_name='live', num_participants=2
        )

        participants = (
            Participant.objects.filter(session=session).order_by(
                'id'
            )  # corresponds to id_in_group
            # .values_list('code', flat=True)
        )

        self.client.get(participants[0]._start_url(), follow=True)

        pc1 = participants[0].code
        pc2 = participants[1].code

        page_name = page_sequence[0].__name__

        specs = dict(
            return_to_0={pc1: True, pc2: True},
            return_to_1={pc1: True},
            different_return={pc1: True, pc2: False},
            no_return=None,
        )

        with patch('otree.live._live_send_back') as mock_send_back:
            for msg, expected in specs.items():
                live_payload_function(pc1, page_name, msg)
                if expected:
                    mock_send_back.assert_called_with(session.code, 1, expected)

        group = Group.objects.first()
        assert group.set_in_no_return == True
        assert group.set_in_return_to_0 == True
