from .utils import TestCase
from otree.session import create_session
from tests.query_api.models import Player, Group, Subsession
from otree.models.participant import Participant


class ObjectModelTests(TestCase):
    def test_fk_lookups(self):
        '''Sanity tests for FK lookups'''

        session = create_session('query_api', num_participants=4)
        subsession = Subsession.objects.get(session=session, round_number=1)
        player = Player.objects.filter(session=session, round_number=1).first()

        subsessions = [player.group.subsession, subsession, player.subsession]

        sessions = [
            player.session,
            player.group.session,
            player.subsession.session,
            player.participant.session,
        ]

        self.assertTrue(all([sub == subsessions[0] for sub in subsessions]))

        self.assertTrue(all([s == sessions[0] for s in sessions]))

    def test_get_players(self):
        '''get_players should always return the same order'''
        session = create_session('query_api', num_participants=4)
        subsessions = session.get_subsessions()
        s1 = subsessions[0]
        s2 = subsessions[1]

        self.assertEqual(
            [p.participant_id for p in s1.get_players()],
            [p.participant_id for p in s2.get_players()],
        )

    def test_query(self):
        session = create_session('query_api', num_participants=4)
        subsession = Subsession.objects.get(session=session, round_number=1)

        groups = subsession.get_groups()
        self.assertIsInstance(groups, list)
        self.assertEqual([g.id_in_subsession for g in groups], [1, 2])

        players = subsession.get_players()
        self.assertIsInstance(players, list)
        self.assertIsInstance(players[0], Player)
        self.assertEqual([p.id_in_subsession for p in players], [1, 2, 3, 4])

        self.assertEqual(
            [p.id_in_subsession for p in players[0].get_others_in_subsession()],
            [2, 3, 4],
        )

        group = groups[0]
        self.assertIsInstance(group, Group)
        g_players = group.get_players()
        self.assertIsInstance(g_players, list)
        player = g_players[0]
        self.assertIsInstance(player, Player)

        self.assertEqual([p.id_in_group for p in g_players], [1, 2])

        p1 = group.get_player_by_id(1)
        self.assertEqual(p1.id_in_group, 1)

        self.assertEqual([p.id_in_group for p in p1.get_others_in_group()], [2])

        pA = group.get_player_by_role('A')
        self.assertEqual(pA.role(), 'A')

    def test_attributes(self):
        '''test misc attributes of API, especially ones that may not have
        coverage elsewhere'''
        session = create_session('query_api', num_participants=2)
        self.assertEqual(session.num_participants, 2)

        # make sure it goes up to num_participants
        self.assertTrue(session.participant_set.filter(id_in_session=2).exists())
