from django.core.management import call_command, CommandError

import os
from unittest.mock import patch
from .utils import TestCase, cd
from tempfile import TemporaryDirectory

# from otree.management.commands.startproject import Command as StartProjectCommand


class StartProjectTests(TestCase):

    # py3.7 docs say to do @patch('__main__.input')
    # but that doesn't work for me
    @patch('builtins.input')
    @patch('django.core.management.templates.urlretrieve')
    def test_startproject_fail(self, patched_urlretrieve, patched_input):
        '''
        if startproject aborts, we should clean up the empty project folder
        '''

        # simulate the user choosing to download sample games
        patched_input.return_value = 'y'
        patched_urlretrieve.side_effect = IOError

        with TemporaryDirectory() as root:
            with cd(root):
                # when startproject is called at the command line, the exception
                # is caught because run_from_argv catches CommandError.
                # but when we use call_command, it doesn't go through run_from_argv,
                # so we need to catch the CommandError.
                with self.assertRaises(CommandError):
                    call_command('startproject', 'foobar')
                self.assertEqual(len(os.listdir(root)), 0)
