from django.urls import reverse

from otree.models import Session
from otree.session import create_session
from .utils import TestCase


class TestSessionAdmin(TestCase):
    def setUp(self):
        create_session('misc_3p', num_participants=9)
        self.session = Session.objects.get()
        self.client.login()

    def test_tabs(self):
        p1 = self.session.participant_set.first()
        # have to load 1 participant so that the monitor view shows data
        self.client.get(p1._start_url(), follow=True)

        tabs = [
            'SessionDescription',
            'SessionMonitor',
            'SessionPayments',
            'SessionData',
            'SessionStartLinks',
            'SessionSplitScreen',
        ]
        urls = [reverse(PageName, args=[self.session.code]) for PageName in tabs]

        for url in urls:
            response = self.client.get(url, follow=True)
            if response.status_code != 200:
                raise Exception('{} returned 400'.format(url))

    def test_edit_session_properties(self):
        path = '/SessionEditProperties/{}/'.format(self.session.code)

        data = {
            'label': 'label_foo',
            'comment': 'comment_foo',
            'participation_fee': '3.14',
            'real_world_currency_per_point': '0.0314',
        }

        resp = self.client.post(path=path, data=data, follow=True)
        self.assertEqual(resp.status_code, 200)

        resp = self.client.get(path, follow=True)
        self.assertEqual(resp.status_code, 200)

        html = resp.content.decode('utf-8')
        for val in data.values():
            self.assertIn(val, html)
