from otree.session import SessionConfig, SessionConfigError, get_session_configs_dict
from .utils import TestCase


# need to add participation_fee and real_world_currency_per_point
# manually, usually it is in SESSION_CONFIG_DEFAULTS

SESSION_CONFIG_DEFAULTS = dict(participation_fee=1, real_world_currency_per_point=0)

GOOD_CONFIGS = [dict(name='a', app_sequence=['a'], 漢=1, num_demo_participants=None)]

BAD_CONFIGS = [
    # duplicates in app_sequence
    dict(name='a', app_sequence=['a', 'a'], num_demo_participants=1),
    # empty app sequence
    dict(name='a', app_sequence=[], num_demo_participants=1),
    # missing num_demo_participants
    dict(name='a', app_sequence=['a']),
]


class SessionConfigTests(TestCase):
    def test_good(self):
        for config in GOOD_CONFIGS:
            get_session_configs_dict([config], SESSION_CONFIG_DEFAULTS)

    def test_bad(self):
        for config in BAD_CONFIGS:
            with self.assertRaises(SessionConfigError):
                get_session_configs_dict([config], SESSION_CONFIG_DEFAULTS)

    def test_duplicate_configs(self):
        config = dict(name='a', app_sequence=['a'], num_demo_participants=None)
        with self.assertRaises(SessionConfigError):
            get_session_configs_dict([config, config], SESSION_CONFIG_DEFAULTS)
