# if there's an error loading the user's module, should print a colored traceback
from .utils import TestCase
import sys
import subprocess
import os
from os.path import dirname, abspath, join
import pytest
import sys
from pathlib import Path
from django.test import override_settings


@pytest.mark.slow
class StartupErrorTests(TestCase):
    '''test this because i had a bug in print_colored_traceback_and_exit
    where i was referencing settings.BASE_DIR, and that caused a situation
    where if the user's models.py or pages.py could not load because
    of a syntax error etc, they would just get a confusing error like
    'devserver: command not found'
    without pointing to the cause of the error in their source.
    '''

    def test_syntax_error_in_models(self):
        '''would be nicer if we can make sure it prints out in the correct color,
        but i'm not sure how to do that'''
        self.run_project(
            'proj1', 'this is a syntax error', 'models.py', check_stderr=False
        )

    def test_name_error_in_views(self):
        self.run_project(
            'proj2', 'ThisWillCauseANameError', 'pages.py', check_stderr=True
        )

    def run_project(self, proj_name, expected_substring, filename, check_stderr=False):
        test_proj_path = join(
            dirname(abspath(__file__)), 'startup_test_projects', proj_name
        )
        args = [sys.executable, 'manage.py', 'devserver']
        env = os.environ.copy()
        del env['DJANGO_SETTINGS_MODULE']

        file_path = Path(test_proj_path, 'foo', filename)
        # dynamically add the syntax error so pycharm doesn't flag the file tree
        # in red
        file_path.write_text(expected_substring, encoding='utf8')
        try:
            process = subprocess.Popen(
                args,
                cwd=test_proj_path,
                env=env,
                stdout=subprocess.PIPE,
                stderr=subprocess.PIPE,
            )
            out, err = process.communicate()
            haystack = err if check_stderr else out
            substring_as_bytes = bytes(expected_substring, encoding='utf8')
            self.assertIn(substring_as_bytes, haystack)
        finally:
            file_path.unlink()


def test_no_redis():
    from channels.layers import get_channel_layer, InMemoryChannelLayer

    assert isinstance(get_channel_layer(), InMemoryChannelLayer)
