import random

from django.template import Context, Template

from otree.currency import Currency as c
from otree.staticfiles import BackslashError
from .utils import TestCase


class Wrapper:
    class BaseTestFilters(TestCase):

        import_statement = ''

        def parse(self, fragment):
            return Template(self.import_statement + fragment)

        def render(self, fragment, context=None):
            if context is None:
                context = Context()
            if not isinstance(context, Context):
                context = Context(context)
            return self.parse(fragment).render(context)

        def test_abs_value(self):
            for value in [0, 1, random.random(), c(1)]:
                actual = self.render("{{value|abs}}", context={'value': value})
                expected = str(value)
                self.assertEqual(actual, expected)

                nvalue = -value
                expected = self.render("{{value|abs}}", context={'value': nvalue})
                self.assertEqual(actual, expected)

            with self.assertRaises(TypeError):
                self.render("{{value|abs}}", context={'value': "foo"})
            with self.assertRaises(TypeError):
                self.render("{{value|abs}}", context={'value': None})

        def test_currency_filter(self):
            with self.settings(USE_POINTS=False, REAL_WORLD_CURRENCY_CODE='USD'):
                self.assertEqual(self.render('{{1|c}}'), '$1.00')

        def test_json(self):
            for python_input, expected_output in [
                (None, 'null'),
                (c(1), '1.0'),
                ("hi", '"hi"'),
                ({"a": 1}, '{"a": 1}'),
            ]:
                output = self.render("{{value|json}}", context={'value': python_input})
                self.assertEqual(output, expected_output)


class TagFilterTests(Wrapper.BaseTestFilters):
    import_statement = '{% load otree %}'


class TagFilterLegacyTests(Wrapper.BaseTestFilters):
    import_statement = '{% load otree_tags %}'


class StaticBackslashTests(TestCase):
    def test_static_with_backslash(self):

        bad_list = [r'a\\t', r'a\n', r'a\r', r'a\1', r'a\X']

        for s in bad_list:
            with self.assertRaises(BackslashError, msg=s):
                body = '{% load otree %} {% static "' + s + '" %}'
                Template(body).render(Context({}))
